// https://umijs.org/config/
import { defineConfig } from 'umi';
import defaultSettings from './defaultSettings';
import proxy from './proxy';

const { REACT_APP_ENV } = process.env;

export default defineConfig({
  hash: true,
  antd: {},
  dva: {
    hmr: true,
  },
  history: {
    type: 'hash',
  },
  locale: {
    // default zh-CN
    default: 'zh-CN',
    antd: true,
    // default true, when it is true, will use `navigator.language` overwrite default
    baseNavigator: true,
  },
  dynamicImport: {
    loading: '@/components/PageLoading/index',
  },
  targets: {
    ie: 11,
  },
  // umi routes: https://umijs.org/docs/routing
  routes: [
    {
      path: '/',
      component: '../layouts/BlankLayout',
      routes: [
        {
          path: '/user',
          component: '../layouts/UserLayout',
          routes: [
            {
              path: '/user/login',
              name: 'login',
              component: './User/login',
            },
            {
              path: '/user',
              redirect: '/user/login',
            },
            {
              name: 'register-result',
              icon: 'smile',
              path: '/user/register-result',
              component: './user/register-result',
            },
            {
              name: 'register',
              icon: 'smile',
              path: '/user/register',
              component: './user/register',
            },
            {
              component: '404',
            },
          ],
        },
        {
          path: '/',
          component: '../layouts/BasicLayout',
          routes: [
            {
              path: '/',
              redirect: '/agent/list',
            },
            {
              path: '/agent',
              name: '代理商管理',
              icon: 'dashboard',
              routes: [
                {
                  name: '代理商列表',
                  icon: 'smile',
                  path: '/agent/list',
                  component: './agent/list',
                }
              ]
            },
            {
              path: '/tieba',
              name: '贴吧管理',
              icon: 'dashboard',
              routes: [
                {
                  name: '分类管理',
                  icon: 'smile',
                  path: '/tieba/Classify',
                  component: './tieba/classify',
                },
                {
                  name: '贴吧板块',
                  icon: 'smile',
                  path: '/tieba/plate',
                  component: './tieba/plate',
                },
                {
                  name: '帖子管理',
                  icon: 'smile',
                  path: '/tieba/posts',
                  component: './tieba/posts',
                },
              ]
            },
            {
              path: '/notice',
              name: '公告管理',
              icon: 'dashboard',
              component: './notice',
            },
            {
              path: '/complaint',
              name: '投诉管理',
              icon: 'dashboard',
              routes: [
                {
                  name: '帖子列表',
                  icon: 'smile',
                  path: '/complaint/admin',
                  component: './complaint/admin',
                }
              ]
            }
          ]
        }
      ],
    },
  ],
  // Theme for antd: https://ant.design/docs/react/customize-theme-cn
  theme: {
    'primary-color': defaultSettings.primaryColor,
  },
  title: false,
  ignoreMomentLocale: true,
  proxy: proxy[REACT_APP_ENV || 'dev'],
  manifest: {
    basePath: '/',
  },
});
